import requests
import datetime

class singleStats():

    def __init__(self, apikey=None):
        if not apikey:
            raise ValueError("Please enter apikey")
        else:
            testReq = requests.get(f"https://public-api.tracker.gg/v2/apex/standard/profile/origin/test", headers={"TRN-Api-Key":f"{apikey}"})

            if str(testReq) == "<Response [401]>":
                raise ValueError("ApiKey is wrong")
            else:
                self.apiKey = apikey 

    def recentlyPlayed(self, userId : str, userPlatform="origin"):
    
        primReq = requests.get(f"https://public-api.tracker.gg/v2/apex/standard/profile/{userPlatform}/{userId}", headers={"TRN-Api-Key":f"{self.apiKey}"})
        # we check whether the account exists or not

        if str(primReq) == "<Response [200]>":
            charactersPlayed = []

            # we make a list using a for loop

            for i in range(len(primReq.json()["data"]["segments"])):
                segReq = primReq.json()["data"]["segments"][i]["metadata"]["name"]
                charactersPlayed.append(segReq)
            charactersPlayed.remove("Lifetime")
            return charactersPlayed

        # we check whether the api key is working

        else:
            raise Exception("This account doesn't exist")

    def matchHistory(self, userId : str, gameCount : int, userPlatform="origin"):

        primReq = requests.get(f"https://public-api.tracker.gg/v2/apex/standard/profile/{userPlatform}/{userId}/sessions", headers={"TRN-Api-Key":f"{self.apiKey}"})
        segReq = primReq.json()
        if str(primReq) == "<Response [200]>":

            data = []

            for i in range(gameCount):
                matchDict = dict() 
                matchDict["legend"] = segReq['data']['items'][i]["matches"][0]["metadata"]["character"]["displayValue"]
                matchDict["kills"] = segReq['data']['items'][i]['stats']['kills']["value"]
                matchDict["duration"] = float(segReq['data']['items'][i]['metadata']['duration']['value'][3:].replace(':', '.'))
                data.append(matchDict)
            return data
        else:
            raise Exception("This account doesn't exist")



from distutils.core import setup

setup(
  name = 'apex_stats',         # How you named your package folder (MyLib)
  packages = ['apex_stats'],   # Chose the same as "name"
  version = '0.1.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'API wrapper for https://apex.tracker.gg',   # Give a short description about your library
  author = 'Bobo Kara',                   # Type in your name
  author_email = 'yamozha16@protonmail.ch',      # Type in your E-Mail
  url = 'https://github.com/yamozha/apex_stats',   # Provide either the link to your github or to your website
)
